@@ -23,20 +23,29 @@
 
 #include "iconset.h"
 
-class AlertIcon : public Icon
+class QPixmap;
+class Impix;
+class QString;
+class QIcon;
+class QImage;
+
+class AlertIcon : public PsiIcon
 {
 	Q_OBJECT
 public:
-	AlertIcon(const Icon *icon);
+	AlertIcon(const PsiIcon *icon);
 	~AlertIcon();
 
-	bool isAnimated() const;
-	const QPixmap &pixmap() const;
-	const QImage &image() const;
-	const QIconSet & iconSet() const;
-	const Impix &impix() const;
-	int framenumber() const;
-	const QString &name() const;
+	// reimplemented
+	virtual bool isAnimated() const;
+	virtual const QPixmap &pixmap() const;
+	virtual const QImage &image() const;
+	virtual const QIcon & icon() const;
+	virtual const Impix &impix() const;
+	virtual int frameNumber() const;
+	virtual const QString &name() const;
+
+	virtual PsiIcon *copy() const;
 
 public slots:
 	void activated(bool playSound = true);
