@@ -130,7 +130,7 @@ void ChatDlg::init()
 	QTimer::singleShot(10, this, SLOT(initComposing()));
 	connect(this, SIGNAL(composing(bool)), SLOT(updateIsComposing(bool)));
 
-	setAcceptDrops(TRUE);
+	setAcceptDrops(true);
 	updateContact(jid(), true);
 
 	X11WM_CLASS("chat");
@@ -271,7 +271,7 @@ bool ChatDlg::readyToHide()
 	// Reset 'contact is composing' & cancel own composing event
 	resetComposing();
 	setChatState(StateGone);
-	if (contactChatState_ == StateComposing || contactChatState_ == StateInactive) {
+	if (contactChatState_ == XMPP::StateComposing || contactChatState_ == XMPP::StateInactive) {
 		setContactChatState(StatePaused);
 	}
 
@@ -642,6 +642,10 @@ void ChatDlg::doSend()
 	if (chatEdit()->text() == "/clear") {
 		chatEdit()->clear();
 		doClear();
+		QString line1,line2;
+		MiniCommand_Depreciation_Message("/clear", "clear", line1, line2);
+		appendSysMsg(line1);
+		appendSysMsg(line2);
 		return;
 	}
 
@@ -974,7 +978,7 @@ void ChatDlg::addEmoticon(QString text)
 	if (!isActiveTab())
 		return;
 
-	chatEdit()->insert(text + " ");
+	chatEdit()->insert(text + ' ');
 }
 
 /**
