@@ -1149,7 +1149,7 @@ QString EventDlg::expandAddresses(const QString &in, bool enc) const
 		if(j.resource().isEmpty())
 			jid = u->jid().full();
 		else
-			jid = u->jid().userHost() + '/' + j.resource();
+			jid = u->jid().withResource(j.resource());
 
 		QString name;
 		if(!u->name().isEmpty())
@@ -1264,7 +1264,7 @@ QString EventDlg::jidToString(const Jid &jid, const QString &r) const
 		if(r.isEmpty())
 			j = u->jid().full();
 		else
-			j = u->jid().userHost() + '/' + r;
+			j = Jid(u->jid().bare()).withResource(r).full();
 
 		if(!u->name().isEmpty())
 			name = u->name() + QString(" <%1>").arg(JIDUtil::encode822(j));
@@ -1507,10 +1507,7 @@ void EventDlg::doChat()
 	if(list.isEmpty())
 		return;
 
-	// FIXME: Maybe it's better without bare(), but then PsiAccount::actionChat
-	// doesn't find the UserListItem to chat with :-(
-	Jid jf(list[0]);
-	Jid j(jf.bare());
+	Jid j(list[0]);
 	aChat(j);
 }
 
@@ -1862,7 +1859,7 @@ void EventDlg::updateEvent(PsiEvent *e)
 		QString txt = xhtml ? m.html().toString("div") : TextUtil::plain2rich(m.body());
 
 		// show subject line if the incoming message has one
-		if(m.subject() != "" && !PsiOptions::instance()->getOption("options.ui.message.show-subjects").toBool())
+		if(!m.subject().isEmpty() && !PsiOptions::instance()->getOption("options.ui.message.show-subjects").toBool())
 			txt = "<p><font color=\"red\"><b>" + tr("Subject:") + " " + TextUtil::plain2rich(m.subject()) + "</b></font></p>" + (xhtml? "" : "<br>") + txt;
 
 		if (!xhtml) {
