@@ -885,7 +885,7 @@ void FileRequestDlg::ft_connected()
 	d->ft = 0;
 	closeDialogs(this);
 	close();
-	bringToFront(w);
+	w->showWithoutActivation();
 
 	w->takeTransfer(h, 0, 0);
 }
@@ -1548,7 +1548,7 @@ public:
 };
 
 FileTransDlg::FileTransDlg(PsiCon *psi)
-:QDialog(0, 0, false, psi_dialog_flags)
+:AdvancedWidget<QDialog>(0, psi_dialog_flags)
 {
 	d = new Private(this);
 	d->psi = psi;
