@@ -24,6 +24,7 @@
 #include <Q3Header>
 #include <Q3TextDrag>
 #include <Q3PopupMenu>
+#include <QtDebug>
 
 #include "capsmanager.h"
 #include "psitooltip.h"
@@ -146,6 +147,7 @@ GCUserView::GCUserView(QWidget* parent)
 
 	connect(this, SIGNAL(doubleClicked(Q3ListViewItem *)), SLOT(qlv_doubleClicked(Q3ListViewItem *)));
 	connect(this, SIGNAL(contextMenuRequested(Q3ListViewItem *, const QPoint &, int)), SLOT(qlv_contextMenuRequested(Q3ListViewItem *, const QPoint &, int)));
+	connect(this, SIGNAL(mouseButtonClicked(int, Q3ListViewItem*, const QPoint&, int)), SLOT(qlv_mouseButtonClicked(int, Q3ListViewItem*, const QPoint&, int)));
 }
 
 GCUserView::~GCUserView()
@@ -326,12 +328,12 @@ void GCUserView::qlv_contextMenuRequested(Q3ListViewItem *i, const QPoint &pos,
 	bool self = gcDlg_->nick() == i->text(0);
 	GCUserViewItem* c = (GCUserViewItem*) findEntry(gcDlg_->nick());
 	if (!c) {
-		qWarning(QString("groupchatdlg.cpp: Self ('%1') not found in contactlist").arg(gcDlg_->nick()));
+		qWarning() << QString("groupchatdlg.cpp: Self ('%1') not found in contactlist").arg(gcDlg_->nick());
 		return;
 	}
 	Q3PopupMenu *pm = new Q3PopupMenu;
-	pm->insertItem(IconsetFactory::icon("psi/sendMessage").icon(), tr("Send &message"), 0);
-	pm->insertItem(IconsetFactory::icon("psi/start-chat").icon(), tr("Open &chat window"), 1);
+	pm->insertItem(IconsetFactory::icon("psi/sendMessage").icon(), tr("Send &Message"), 0);
+	pm->insertItem(IconsetFactory::icon("psi/start-chat").icon(), tr("Open &Chat Window"), 1);
 	pm->insertSeparator();
 	pm->insertItem(tr("&Kick"),10);
 	pm->setItemEnabled(10, MUCManager::canKick(c->s.mucItem(),lvi->s.mucItem()));
@@ -348,7 +350,7 @@ void GCUserView::qlv_contextMenuRequested(Q3ListViewItem *i, const QPoint &pos,
 	rm->insertItem(tr("Moderator"),14);
 	rm->setItemChecked(14, lvi->s.mucItem().role() == MUCItem::Moderator);
 	rm->setItemEnabled(14, (!self || lvi->s.mucItem().role() == MUCItem::Moderator) && MUCManager::canSetRole(c->s.mucItem(),lvi->s.mucItem(),MUCItem::Moderator));
-	pm->insertItem(tr("Change role"),rm);
+	pm->insertItem(tr("Change Role"),rm);
 
 	/*Q3PopupMenu* am = new Q3PopupMenu(pm);
 	am->insertItem(tr("Unaffiliated"),15);
@@ -363,9 +365,9 @@ void GCUserView::qlv_contextMenuRequested(Q3ListViewItem *i, const QPoint &pos,
 	am->insertItem(tr("Owner"),18);
 	am->setItemChecked(18, lvi->s.mucItem().affiliation() == MUCItem::Owner);
 	am->setItemEnabled(18,  (!self || lvi->s.mucItem().affiliation() == MUCItem::Owner) && MUCManager::canSetAffiliation(c->s.mucItem(),lvi->s.mucItem(),MUCItem::Owner));
-	pm->insertItem(tr("Change affiliation"),am);*/
+	pm->insertItem(tr("Change Affiliation"),am);*/
 	pm->insertSeparator();
-	//pm->insertItem(tr("Send &file"), 4);
+	//pm->insertItem(tr("Send &File"), 4);
 	//pm->insertSeparator();
 	pm->insertItem(tr("Check &Status"), 2);
 	pm->insertItem(IconsetFactory::icon("psi/vCard").icon(), tr("User &Info"), 3);
@@ -377,3 +379,15 @@ void GCUserView::qlv_contextMenuRequested(Q3ListViewItem *i, const QPoint &pos,
 		return;
 	action(lvi->text(0), lvi->s, x);
 }
+
+void GCUserView::qlv_mouseButtonClicked(int button, Q3ListViewItem* item, const QPoint& pos, int c)
+{
+	Q_UNUSED(pos);
+	Q_UNUSED(c);
+	if (!item || !item->parent() || !gcDlg_)
+		return;
+	if (button != Qt::MidButton)
+		return;
+
+	emit insertNick(item->text(0));
+}
