@@ -39,7 +39,6 @@ class PsiAccount;
 class PsiOptions;
 class QRect;
 class GCMainDlg;
-class QPainter;
 class QColorGroup;
 class Q3DragObject;
 namespace XMPP {
@@ -76,6 +75,9 @@ public:
 	void setPassword(const QString&);
 	const QString& nick() const;
 
+	bool isInactive() const;
+	void reactivate();
+
 	// reimplemented
 	virtual TabbableWidget::State state() const;
 	virtual int unreadMessageCount() const;
@@ -113,6 +115,7 @@ private slots:
 	void pa_updatedActivity();
 	void goDisc();
 	void goConn();
+	void goForcedLeave();
 	void lv_action(const QString &, const Status &, int);
 	void doClear();
 	void doClearButton();
@@ -140,6 +143,10 @@ private:
 	void updateLastMsgTime(QDateTime t);
 	void setLooks();
 
+	void mucKickMsgHelper(const QString &nick, const Status &s, const QString &nickJid, const QString &title,
+			const QString &youSimple, const QString &youBy, const QString &someoneSimple,
+			const QString &someoneBy);
+
 	void contextMenuEvent(QContextMenuEvent *);
 
 	QString getNickColor(QString);
