@@ -33,6 +33,7 @@
 #include <QtCrypto>
 #include <QTranslator>
 #include <QDir>
+#include <QProcess>
 
 #include <stdlib.h>
 #include <time.h>
@@ -51,13 +52,17 @@
 #endif
 
 #ifdef Q_WS_MAC
-#include "cocoautil.h"
+#include "CocoaUtilities/CocoaInitializer.h"
 #endif
 
 #ifdef Q_OS_WIN
 #	include <qt_windows.h> // for RegDeleteKey
 #endif
 
+#ifdef Q_OS_WIN
+#define URI_RESTART
+#endif
+
 /** \mainpage Psi API Documentation
  *
  *	\section intro_sec Indroduction
@@ -74,12 +79,13 @@
 
 using namespace XMPP;
 
-PsiMain::PsiMain(QObject *par)
-:QObject(par)
+PsiMain::PsiMain(const QString& uriToOpen, QObject *par)
+	: QObject(par)
+	, uri(uriToOpen)
 {
 	pcon = 0;
 
-	// load simple registry settings
+	// migrate old (pre 0.11) registry settings...
 	QSettings sUser(QSettings::UserScope, "psi-im.org", "Psi");
 	lastProfile = sUser.value("last_profile").toString();
 	lastLang = sUser.value("last_lang").toString();
@@ -122,15 +128,8 @@ PsiMain::PsiMain(QObject *par)
 			QMessageBox::critical(0, tr("Error"), 
 				tr("There was an error creating the default profile."));
 			QTimer::singleShot(0, this, SLOT(bail()));
-		}
-		else {
-			PsiOptions o;
-			if (!o.newProfile()) {
-				qWarning("ERROR: Failed to new profile default options");
-			}
-
-			o.save(pathToProfile("default") + "/options.xml");
-
+		} else {
+			// options.xml will be created by PsiCon::init
 			lastProfile = activeProfile = "default";
 			autoOpen = true;
 			QTimer::singleShot(0, this, SLOT(sessionStart()));
@@ -142,26 +141,6 @@ PsiMain::~PsiMain()
 {
 	delete pcon;
 
-// Removed QSettings stuff for windows, don't think it's necessary anymore (remko)
-/*
-#ifdef Q_OS_WIN
-	// remove Psi's settings from HKLM
-	QSettings *rs = new QSettings;
-	rs->setPath("Affinix", "psi", QSettings::SystemScope);
-	rs->removeEntry("/lastProfile");
-	rs->removeEntry("/lastLang");
-	rs->removeEntry("/autoOpen");
-
-	QString affinixKey = "Software\\Affinix";
-#ifdef Q_OS_TEMP
-	RegDeleteKeyW(HKEY_LOCAL_MACHINE, affinixKey.ucs2());
-#else
-	RegDeleteKeyA(HKEY_LOCAL_MACHINE, affinixKey.latin1());
-#endif
-	delete rs;
-#endif
-*/
-	//QSettings s(QSettings::UserScope, "psi-im.org", "Psi");
 	QSettings s(ApplicationInfo::homeDir() + "/psirc", QSettings::IniFormat);
 	s.setValue("last_profile", lastProfile);
 	s.setValue("last_lang", lastLang);
@@ -234,23 +213,29 @@ void PsiMain::chooseProfile()
 
 void PsiMain::sessionStart()
 {
-	// make sure we have clean PsiOptions
-	PsiOptions::reset();
-	// get a PsiCon
 	if (!ActiveProfiles::instance()->setThisProfile(activeProfile)) { // already running
-		if (!ActiveProfiles::instance()->raiseOther(activeProfile, true))
+		if (!ActiveProfiles::instance()->raiseOther(activeProfile, true)) {
 			QMessageBox::critical(0, tr("Error"), tr("Cannot open this profile - it is already running, but not responding"));
+		}
 		quit();
 		return;
 	}
+
+	// make sure we have clean PsiOptions
+	PsiOptions::reset();
+	// get a PsiCon
 	pcon = new PsiCon();
-	if(!pcon->init()) {
+	if (!pcon->init()) {
 		delete pcon;
 		pcon = 0;
 		quit();
 		return;
 	}
 	connect(pcon, SIGNAL(quit(int)), SLOT(sessionQuit(int)));
+	if (!uri.isEmpty()) {
+		pcon->doOpenUri(uri);
+		uri.clear();
+	}
 }
 
 void PsiMain::sessionQuit(int x)
@@ -272,10 +257,163 @@ void PsiMain::bail()
 	quit();
 }
 
+#ifdef URI_RESTART
+// all printable chars except for space, dash, and double-quote are
+//   backslash-escaped.
+static QByteArray encodeUri(const QByteArray &in)
+{
+	QByteArray out;
+	for(int n = 0; n < in.size(); ++n) {
+		unsigned char c = (unsigned char)in[n];
+		if(c == '\\') {
+			out += "\\\\";
+		}
+		else if(c >= 0x21 && c < 0x7f && c != '-' && c != '\"') {
+			out += in[n];
+		}
+		else {
+			char hex[5];
+			qsnprintf(hex, 5, "\\x%02x", c);
+			out += QByteArray::fromRawData(hex, 4);
+		}
+	}
+	return out;
+}
+
+static QString decodeUri(const QString &in)
+{
+	// note that the input is an 8-bit text encoding which is then escaped,
+	//   and the result is a latin1-compatible string.  to decode this, we
+	//   need to first unescape back to 8-bit, and then decode the 8-bit
+	//   into unicode
+
+	QByteArray dec;
+	for(int n = 0; n < in.length(); ++n) {
+		if(in[n] == '\\') {
+			if(n + 1 < in.length()) {
+				++n;
+				if(in[n] == '\\') {
+					dec += '\\';
+				}
+				else if(in[n] == 'x') {
+					if(n + 2 < in.length()) {
+						++n;
+						QString xs = in.mid(n, 2);
+						++n;
+						bool ok = false;
+						int x = xs.toInt(&ok, 16);
+						if(ok) {
+							unsigned char c = (unsigned char)x;
+							dec += c;
+						}
+					}
+				}
+			}
+		}
+		else
+			dec += in[n].toLatin1();
+	}
+
+	return QString::fromLocal8Bit(dec);
+}
+
+// NOTE: this function is called without qapp existing
+static int restart_process(int argc, char **argv, const QByteArray &uri)
+{
+	// FIXME: in the future we should use CreateProcess instead, but for
+	//   now it is easier to use qprocess, and it should be safe if
+	//   qcoreapp is used instead of qapp which i believe does not read
+	//   args
+	/*BOOL ret;
+	QT_WA(
+		ret = CreateProcessW();
+	,
+		ret = CreateProcessA();
+	)*/
+
+	// re-run ourself, with encoded uri
+	QCoreApplication qapp(argc, argv);
+	QString selfExe = QCoreApplication::applicationFilePath();
+
+	// don't use QCoreApplication::arguments(), because that calls
+	//   GetCommandLine which is not clipped.  instead, use the provided
+	//   argc/argv.
+	QStringList args;
+	for(int n = 1; n < argc; ++n) {
+		args += QString::fromLocal8Bit(argv[n]);
+	}
+
+	if(!uri.isEmpty()) {
+		args += QString("--encuri=") + QString::fromLatin1(encodeUri(uri));
+	}
+
+	if(QProcess::startDetached(selfExe, args)) {
+		return 0;
+	}
+	else {
+		return 1;
+	}
+}
+#endif
+
 int main(int argc, char *argv[])
 {
-	// it must be initialized first in order for ApplicationInfo::resourcesDir() to work
+	// If Psi runs as uri handler the commandline might contain
+	// almost arbitary network supplied data after the "--uri" argument.
+	// To prevent any potentially dangerous options in Psi or
+	// Qt to be triggered by this, filter out the uri and any following
+	// data as early as possible.  We even filter before qca init, just in
+	// case qca ever decides to check commandline arguments in a future
+	// version.
+	// see http://www.mozilla.org/security/announce/2007/mfsa2007-23.html
+	// for how this problem affected firefox on windows.
+
+	QByteArray uriBA;
+	for (int i=1; i<argc; i++) {
+		QByteArray str = QByteArray(argv[i]);
+		QByteArray var, val;
+		int x = str.find('=');
+		if(x == -1) {
+			var = str;
+			val = "";
+		} else {
+			var = str.mid(0,x);
+			val = str.mid(x+1);
+		}
+
+		if (var == "--uri") {
+			uriBA = val;
+			if (uriBA.isEmpty() && i+1 < argc) {
+				uriBA = QByteArray(argv[i+1]);
+			}
+
+			// terminate args here. Everything that follows mustn't
+			// be availible in later commandline scanning.
+#ifdef URI_RESTART
+			// for windows, we have to do this by restarting the
+			// process
+			return restart_process(i, argv, uriBA);
+#else
+			// otherwise, it should enough to modify argc/argv
+			argc = i;
+			argv[i] = 0;
+			break;
+#endif
+		}
+		
+	}
+
+	// NOTE: Qt 4.5 compatibility note: please don't move this call.
+	//   instead, upgrade to QCA 2.0.2, which fixes the bug in the right
+	//   place.
 	QCA::Initializer init;
+	// END NOTE
+
+#ifdef Q_WS_MAC
+	CocoaInitializer cocoaInitializer;
+#endif
+
+	// it must be initialized first in order for ApplicationInfo::resourcesDir() to work
 	PsiApplication app(argc, argv);
 	QApplication::addLibraryPath(ApplicationInfo::resourcesDir());
 	QApplication::addLibraryPath(ApplicationInfo::homeDir());
@@ -294,11 +432,6 @@ int main(int argc, char *argv[])
 	QCA::KeyStoreManager::start();
 	keystoremgr.waitForBusyFinished(); // FIXME get rid of this
 
-
-#ifdef Q_WS_MAC
-	CocoaUtil::initialize();
-#endif
-
 #ifdef USE_CRASH
 	int useCrash = true;
 	int i;
@@ -316,6 +449,8 @@ int main(int argc, char *argv[])
 	srand(time(NULL));
 
 	//dtcp_port = 8000;
+
+	QString uri = QString::fromLocal8Bit(uriBA);
 	for(int n = 1; n < argc; ++n) {
 		QString str = argv[n];
 		QString var, val;
@@ -329,6 +464,10 @@ int main(int argc, char *argv[])
 			val = str.mid(x+1);
 		}
 
+#ifdef URI_RESTART
+		if(var == "--encuri")
+			uri = decodeUri(val);
+#endif
 		//if(var == "--no-gpg")
 		//	use_gpg = false;
 		//else if(var == "--no-gpg-agent")
@@ -337,6 +476,12 @@ int main(int argc, char *argv[])
 		//	link_test = true;
 	}
 
+	if (!uri.isEmpty()) {
+		if (ActiveProfiles::instance()->sendOpenUri(uri)) {
+			return 0;
+		}
+	}
+
 	//if(link_test)
 	//	printf("Link test enabled\n");
 
@@ -351,7 +496,7 @@ int main(int argc, char *argv[])
 	//if(!QCA::isSupported(QCA::CAP_SHA1))
 	//	QCA::insertProvider(XMPP::createProviderHash());
 
-	PsiMain *psi = new PsiMain;
+	PsiMain *psi = new PsiMain(uri);
 	QObject::connect(psi, SIGNAL(quit()), &app, SLOT(quit()));
 	int returnValue = app.exec();
 	delete psi;
