@@ -36,6 +36,7 @@
 #include <QMenu>
 #include <QMenuItem>
 #include <QtAlgorithms>
+#include <QShortcut>
 
 #ifdef Q_WS_WIN
 #include <windows.h>
@@ -62,8 +63,23 @@
 
 #include "mainwin_p.h"
 
+#include "psimedia/psimedia.h"
+#include "avcall/avcall.h"
+
 using namespace XMPP;
 
+// FIXME: this is a really corny way of getting the GStreamer version...
+QString extract_gst_version(const QString &in)
+{
+	int start = in.indexOf("GStreamer ");
+	if(start == -1)
+		return QString();
+	start += 10;
+	int end = in.indexOf(",", start);
+	if(end == -1)
+		return QString();
+	return in.mid(start, end - start);
+}
 
 //----------------------------------------------------------------------------
 // MainWin::Private
@@ -374,12 +390,17 @@ MainWin::MainWin(bool _onTop, bool _asTool, PsiCon* psi, const char* name)
 	d->getAction("help_online_help")->addTo (helpMenu);
 	d->getAction("help_online_wiki")->addTo (helpMenu);
 	d->getAction("help_online_home")->addTo (helpMenu);
+	d->getAction("help_online_forum")->addTo (helpMenu);
 	d->getAction("help_psi_muc")->addTo (helpMenu);
 	d->getAction("help_report_bug")->addTo (helpMenu);
 	QMenu* diagMenu = new QMenu(this);
 	helpMenu->insertItem(tr("Diagnostics"), diagMenu);
 	d->getAction("help_diag_qcaplugin")->addTo (diagMenu);
 	d->getAction("help_diag_qcakeystore")->addTo (diagMenu);
+	if(AvCallManager::isSupported()) {
+		helpMenu->insertSeparator();
+		d->getAction("help_about_psimedia")->addTo (helpMenu);
+	}
 #else
 	if (!PsiOptions::instance()->getOption("options.ui.contactlist.show-menubar").toBool())  {
 		mainMenuBar()->hide();
@@ -397,6 +418,9 @@ MainWin::MainWin(bool _onTop, bool _asTool, PsiCon* psi, const char* name)
 
 	connect(psi, SIGNAL(emitOptionsUpdate()), SLOT(optionsUpdate()));
 	optionsUpdate();
+
+        /*QShortcut *sp_ss = new QShortcut(QKeySequence(tr("Ctrl+Shift+N")), this);
+        connect(sp_ss, SIGNAL(activated()), SLOT(avcallConfig()));*/
 }
 
 MainWin::~MainWin()
@@ -414,9 +438,9 @@ MainWin::~MainWin()
 
 void MainWin::registerAction( IconAction* action )
 {
-	char activated[] = SIGNAL( activated() );
-	char toggled[]   = SIGNAL( toggled(bool) );
-	char setChecked[]     = SLOT( setChecked(bool) );
+	const char *activated  = SIGNAL( activated() );
+	const char *toggled    = SIGNAL( toggled(bool) );
+	const char *setChecked = SLOT( setChecked(bool) );
 
 	struct {
 		const char* name;
@@ -458,10 +482,12 @@ void MainWin::registerAction( IconAction* action )
 		{ "help_online_help", activated, this, SLOT( actOnlineHelpActivated() ) },
 		{ "help_online_wiki", activated, this, SLOT( actOnlineWikiActivated() ) },
 		{ "help_online_home", activated, this, SLOT( actOnlineHomeActivated() ) },
+		{ "help_online_forum", activated, this, SLOT( actOnlineForumActivated() ) },
 		{ "help_psi_muc",     activated, this, SLOT( actJoinPsiMUCActivated() ) },
 		{ "help_report_bug",  activated, this, SLOT( actBugReportActivated() ) },
 		{ "help_about",       activated, this, SLOT( actAboutActivated() ) },
 		{ "help_about_qt",    activated, this, SLOT( actAboutQtActivated() ) },
+		{ "help_about_psimedia",   activated, this, SLOT( actAboutPsiMediaActivated() ) },
 		{ "help_diag_qcaplugin",   activated, this, SLOT( actDiagQCAPluginActivated() ) },
 		{ "help_diag_qcakeystore", activated, this, SLOT( actDiagQCAKeyStoreActivated() ) },
 
@@ -544,7 +570,7 @@ void MainWin::setWindowOpts(bool _onTop, bool _asTool)
 	}
 
 	QPoint p = pos();
-	reparent(parentWidget(), flags, p, FALSE);
+	reparent(parentWidget(), flags, p, false);
 	move(p);
 	show();
 }
@@ -687,6 +713,7 @@ void MainWin::buildOptionsMenu()
 	        << "help_online_help"
 	        << "help_online_wiki"
 	        << "help_online_home"
+	        << "help_online_forum"
 	        << "help_psi_muc"
 	        << "help_report_bug"
 	        << "diagnostics"
@@ -694,6 +721,9 @@ void MainWin::buildOptionsMenu()
 	        << "help_about"
 	        << "help_about_qt";
 
+	if(AvCallManager::isSupported())
+		actions << "help_about_psimedia";
+
 	d->updateMenu(actions, helpMenu);
 
 	buildGeneralMenu( d->optionsMenu );
@@ -777,6 +807,11 @@ void MainWin::actOnlineHomeActivated ()
 	DesktopUtil::openUrl("http://psi-im.org");
 }
 
+void MainWin::actOnlineForumActivated ()
+{
+    DesktopUtil::openUrl("http://forum.psi-im.org");
+}
+
 void MainWin::actJoinPsiMUCActivated()
 {
 	PsiAccount* account = d->psi->contactList()->defaultAccount();
@@ -789,7 +824,7 @@ void MainWin::actJoinPsiMUCActivated()
 
 void MainWin::actBugReportActivated ()
 {
-	DesktopUtil::openUrl("http://psi-im.org/forum/forum/2");
+	DesktopUtil::openUrl("http://forum.psi-im.org/forum/2");
 }
 
 void MainWin::actAboutActivated ()
@@ -808,6 +843,56 @@ void MainWin::actAboutQtActivated ()
 	QMessageBox::aboutQt(this);
 }
 
+void MainWin::actAboutPsiMediaActivated ()
+{
+	QString creditText = PsiMedia::creditText();
+	QString gstVersion = extract_gst_version(creditText);
+
+	QString str;
+	QPixmap pix;
+	if(!gstVersion.isEmpty())
+	{
+		str = tr(
+			"This application uses GStreamer %1, a comprehensive "
+			"open-source and cross-platform multimedia framework."
+			"  For more information, see "
+			"<a href=\"http://www.gstreamer.net/\">http://www.gstreamer.net/</a>").arg(gstVersion);
+		pix = IconsetFactory::icon("psi/gst_logo").pixmap();
+	}
+	else
+		str = creditText;
+
+	QDialog aboutGst;
+	QVBoxLayout *vb = new QVBoxLayout(&aboutGst);
+	aboutGst.setWindowTitle(tr("About GStreamer"));
+	QHBoxLayout *hb = new QHBoxLayout;
+	vb->addLayout(hb);
+	if(!pix.isNull())
+	{
+		QLabel *la = new QLabel(&aboutGst);
+		la->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed));
+		la->setPixmap(pix);
+		hb->addWidget(la);
+	}
+	QLabel *lb = new QLabel(&aboutGst);
+	lb->setText(str);
+	lb->setTextFormat(Qt::RichText);
+	lb->setWordWrap(true);
+	lb->setOpenExternalLinks(true);
+	hb->addWidget(lb);
+	QDialogButtonBox *buttonBox = new QDialogButtonBox(&aboutGst);
+	buttonBox->addButton(QDialogButtonBox::Ok);
+	aboutGst.connect(buttonBox, SIGNAL(accepted()), SLOT(accept()));
+	vb->addWidget(buttonBox);
+	if(!pix.isNull())
+	{
+		int w = pix.width() * 4;
+		aboutGst.resize(w, aboutGst.heightForWidth(w));
+	}
+	aboutGst.exec();
+	//QMessageBox::about(this, tr("About GStreamer"), str);
+}
+
 void MainWin::actDiagQCAPluginActivated()
 {
 	QString dtext = QCA::pluginDiagnosticText();
@@ -922,7 +1007,7 @@ void MainWin::decorateButton(int status)
 
 bool MainWin::askQuit()
 {
-	return TRUE;
+	return true;
 }
 
 void MainWin::try2tryCloseProgram()
@@ -1380,4 +1465,10 @@ void MainWin::showNoFocus()
 	bringToFront(this);
 }
 
+void MainWin::avcallConfig()
+{
+	if (AvCallManager::isSupported())
+		AvCallManager::config();
+}
+
 //#endif
