@@ -116,10 +116,12 @@ private slots:
 	void actOnlineHelpActivated ();
 	void actOnlineWikiActivated ();
 	void actOnlineHomeActivated ();
+	void actOnlineForumActivated ();
 	void actJoinPsiMUCActivated();
 	void actBugReportActivated ();
 	void actAboutActivated ();
 	void actAboutQtActivated ();
+	void actAboutPsiMediaActivated ();
 	void actPlaySoundsActivated (bool);
 	void actPublishTuneActivated (bool);
 	void actTipActivated();
@@ -147,6 +149,8 @@ public slots:
 
 	void toggleVisible();
 
+	void avcallConfig();
+
 private:
 	void buildGeneralMenu(QMenu *);
 	QString numEventsString(int) const;
