@@ -28,6 +28,7 @@
 #include "psiaccount.h"
 #include "mucjoindlg.h"
 #include "psicontactlist.h"
+#include "groupchatdlg.h"
 
 MUCJoinDlg::MUCJoinDlg(PsiCon* psi, PsiAccount* pa)
 	: QDialog(0)
@@ -88,7 +89,7 @@ void MUCJoinDlg::done(int r)
 		//int n = QMessageBox::information(0, tr("Warning"), tr("Are you sure you want to cancel joining groupchat?"), tr("&Yes"), tr("&No"));
 		//if(n != 0)
 		//	return;
-		account_->groupChatLeave(jid_.host(), jid_.user());
+		account_->groupChatLeave(jid_.domain(), jid_.node());
 	}
 	QDialog::done(r);
 }
@@ -129,8 +130,8 @@ void MUCJoinDlg::recent_activated(int x)
 	if (jid.full().isEmpty())
 		return;
 
-	ui_.le_host->setText(jid.host());
-	ui_.le_room->setText(jid.user());
+	ui_.le_host->setText(jid.domain());
+	ui_.le_room->setText(jid.node());
 	ui_.le_nick->setText(jid.resource());
 }
 
@@ -155,6 +156,17 @@ void MUCJoinDlg::doJoin()
 		return;
 	}
 
+	GCMainDlg *gc = account_->findDialog<GCMainDlg*>(j.bare());
+	if (gc) {
+		gc->bringToFront();
+		if (gc->isInactive()) {
+			gc->reactivate();
+		}
+		joined();
+		return;
+	}
+
+
 	if (!account_->groupChatJoin(host, room, nick, pass, !ui_.ck_history->isChecked())) {
 		QMessageBox::information(this, tr("Error"), tr("You are in or joining this room already!"));
 		return;
@@ -193,13 +205,15 @@ void MUCJoinDlg::error(int, const QString &str)
 	account_->dialogUnregister(this);
 	controller_->dialogRegister(this);
 
-	QMessageBox::information(this, tr("Error"), tr("Unable to join groupchat.\nReason: %1").arg(str));
+	QMessageBox* msg = new QMessageBox(QMessageBox::Information, tr("Error"), tr("Unable to join groupchat.\nReason: %1").arg(str), QMessageBox::Ok, this, Qt::WDestructiveClose);
+	msg->setModal(false);
+	msg->show();
 }
 
 void MUCJoinDlg::setJid(const Jid& mucJid)
 {
-	ui_.le_host->setText(mucJid.host());
-	ui_.le_room->setText(mucJid.user());
+	ui_.le_host->setText(mucJid.domain());
+	ui_.le_room->setText(mucJid.node());
 }
 
 void MUCJoinDlg::setNick(const QString nick)
