@@ -27,6 +27,7 @@
 #include "opt_iconset.h"
 #include "opt_groupchat.h"
 #include "opt_sound.h"
+#include "opt_avcall.h"
 #include "opt_advanced.h"
 #include "opt_shortcuts.h"
 #include "opt_tree.h"
@@ -35,6 +36,8 @@
 #include "opt_plugins.h"
 #endif
 
+#include "../avcall/avcall.h"
+
 //----------------------------------------------------------------------------
 // FancyItem
 //----------------------------------------------------------------------------
@@ -310,6 +313,8 @@ void OptionsDlg::Private::createTabs()
 	//tabs.append( new OptionsTabBase(this, "sound",    "", "psi/playSounds",	tr("Sound"),		tr("Configure how Psi sounds")) );
 	*/
 
+	OptionsTabApplication* applicationTab = new OptionsTabApplication(this);
+	applicationTab->setHaveAutoUpdater(psi->haveAutoUpdater());
 	tabs.append( new OptionsTabApplication(this) );
 	tabs.append( new OptionsTabChat(this) );
 	tabs.append( new OptionsTabEvents(this) );
@@ -320,6 +325,8 @@ void OptionsDlg::Private::createTabs()
 	//tabs.append( new OptionsTabIconsetEmoticons(this) );
 	tabs.append( new OptionsTabGroupchat(this) );
 	tabs.append( new OptionsTabSound(this) );
+	if(AvCallManager::isSupported())
+		tabs.append( new OptionsTabAvCall(this) );
 	tabs.append( new OptionsTabToolbars(this) );
 #ifdef PSI_PLUGINS
 	tabs.append( new OptionsTabPlugins(this) );
@@ -466,7 +473,7 @@ void OptionsDlg::Private::openTab(QString id)
 		}
 	}
 
-	dlg->ws_tabs->raiseWidget( tab );
+	dlg->ws_tabs->setCurrentWidget( tab );
 
 	// and select item in lv_tabs...
 	Q3ListViewItemIterator it( dlg->lv_tabs );
