@@ -5,19 +5,18 @@
 #include <QDialog>
 
 class PsiCon;
-struct Options;
 
 class OptionsDlg : public QDialog, public Ui::OptionsUI
 {
 	Q_OBJECT
 public:
-	OptionsDlg(PsiCon *, const Options &, QWidget *parent = 0);
+	OptionsDlg(PsiCon *, QWidget *parent = 0);
 	~OptionsDlg();
 
 	void openTab(const QString& id);
 
 signals:
-	void applyOptions(const Options &);
+	void applyOptions();
 
 private slots:
 	void doOk();
