@@ -108,32 +108,32 @@ UserAccount::UserAccount()
 void UserAccount::reset()
 {
 	name = "Default";
-	opt_enabled = TRUE;
-	opt_auto = FALSE;
-	tog_offline = TRUE;
-	tog_away = TRUE;
-	tog_hidden = FALSE;
-	tog_agents = TRUE;
-	tog_self = FALSE;
-	customAuth = FALSE;
-	req_mutual_auth = FALSE;
-	legacy_ssl_probe = TRUE;
+	opt_enabled = true;
+	opt_auto = false;
+	tog_offline = true;
+	tog_away = true;
+	tog_hidden = false;
+	tog_agents = true;
+	tog_self = false;
+	customAuth = false;
+	req_mutual_auth = false;
+	legacy_ssl_probe = true;
 	security_level = QCA::SL_None;
 	ssl = SSL_Auto;
 	jid = "";
 	pass = "";
-	opt_pass = FALSE;
+	opt_pass = false;
 	port = 5222;
-	opt_host = FALSE;
+	opt_host = false;
 	host = "";
-	opt_automatic_resource = TRUE;
+	opt_automatic_resource = true;
 	resource = "Psi";
 	priority = 5;
-	opt_keepAlive = TRUE;
+	opt_keepAlive = true;
 	allow_plain = XMPP::ClientStream::AllowPlainOverTLS;
-	opt_compress = FALSE;
-	opt_log = TRUE;
-	opt_reconn = FALSE;
+	opt_compress = false;
+	opt_log = true;
+	opt_reconn = false;
 	opt_connectAfterSleep = false;
 	opt_ignoreSSLWarnings = false;
 
@@ -144,6 +144,8 @@ void UserAccount::reset()
 	proxy_user = "";
 	proxy_pass = "";
 
+	stunPort = 3478;
+
 	keybind.clear();
 
 	roster.clear();
@@ -155,10 +157,16 @@ UserAccount::~UserAccount()
 
 void UserAccount::fromOptions(OptionsTree *o, QString base)
 {
+	// WARNING: If you add any new option here, only read the option if
+	// allSetOptions (defined below) contains the new option. If not
+	// the code should just leave the default value from the reset()
+	// call in place.
 	optionsBase = base;
-	
+
 	reset();
 
+	QStringList allSetOptions = o->getChildOptionNames(base, true, true);
+
 	opt_enabled = o->getOption(base + ".enabled").toBool();
 	opt_auto = o->getOption(base + ".auto").toBool();
 	opt_keepAlive = o->getOption(base + ".keep-alive").toBool();
@@ -188,7 +196,7 @@ void UserAccount::fromOptions(OptionsTree *o, QString base)
 	// read password (we must do this after reading the jid, to decode properly)
 	QString tmp = o->getOption(base + ".password").toString();
 	if(!tmp.isEmpty()) {
-		opt_pass = TRUE;
+		opt_pass = true;
 		pass = decodePassword(tmp, jid);
 	}
 	
@@ -260,6 +268,23 @@ void UserAccount::fromOptions(OptionsTree *o, QString base)
 	keybind.fromOptions(o, base + ".pgp-key-bindings");
 
 	dtProxy = o->getOption(base + ".bytestreams-proxy").toString();
+
+
+	if (allSetOptions.contains(base + ".stun-host")) {
+		stunHost = o->getOption(base + ".stun-host").toString();
+	}
+	if (allSetOptions.contains(base + ".stun-port")) {
+		int tmpPort = o->getOption(base + ".stun-port").toInt();
+		// a few days in the 0.13-dev development cycle the code set
+		// 0 as port when first adding this option. Ignore 0 for now
+		// and use default
+		if (tmpPort != 0) stunPort = tmpPort;
+	}
+
+	if (allSetOptions.contains(base + ".tls")) {
+		tlsOverrideCert = o->getOption(base + ".tls.override-certificate").toByteArray();
+		tlsOverrideDomain = o->getOption(base + ".tls.override-domain").toString();
+	}
 }
 
 void UserAccount::toOptions(OptionsTree *o, QString base)
@@ -377,12 +402,17 @@ void UserAccount::toOptions(OptionsTree *o, QString base)
 		o->setOption(groupBase + ".open", groupState[group].open);
 		o->setOption(groupBase + ".rank", groupState[group].rank);
 	}
-		
+
 	o->setOption(base + ".proxy-id", proxyID);
 
 	keybind.toOptions(o, base + ".pgp-key-bindings");
 	o->setOption(base + ".bytestreams-proxy", dtProxy.full());
-	
+
+	o->setOption(base + ".stun-host", stunHost);
+	o->setOption(base + ".stun-port", QString::number(stunPort));
+
+	o->setOption(base + ".tls.override-certificate", tlsOverrideCert);
+	o->setOption(base + ".tls.override-domain", tlsOverrideDomain);
 }
 
 void UserAccount::fromXml(const QDomElement &a)
@@ -460,7 +490,7 @@ void UserAccount::fromXml(const QDomElement &a)
 	// read password (we must do this after reading the jid, to decode properly)
 	readEntry(a, "password", &pass);
 	if(!pass.isEmpty()) {
-		opt_pass = TRUE;
+		opt_pass = true;
 		pass = decodePassword(pass, jid);
 	}
 
@@ -536,311 +566,6 @@ void UserAccount::fromXml(const QDomElement &a)
 	dtProxy = str;
 }
 
-#if 0
- LEGOPTFIXME
-void OptionsMigration::reset()
-{
-	bool nix, win, mac;
-	nix = win = mac = FALSE;
-
-#ifdef Q_WS_X11
-	nix = TRUE;
-#endif
-#ifdef Q_WS_WIN
-	win = TRUE;
-#endif
-#ifdef Q_WS_MAC
-	mac = TRUE;
-#endif
-
-	// global
-	mwgeom.setRect(64, 64, 150, 360);
-	lastStatusString = "";
-	useSound = TRUE;
-	proxyList.clear();
-	acc.clear();
-
-	// LEGOPTP
-	LEGOPTP.useleft = FALSE;
-	LEGOPTP.singleclick = FALSE;
- 	LEGOPTP.hideMenubar = FALSE;
-	LEGOPTP.defaultAction = 1;
-	LEGOPTP.delChats = dcHour;
-	LEGOPTP.browser = 0;
-	LEGOPTP.alwaysOnTop = FALSE;
-	LEGOPTP.keepSizes = TRUE;
-	LEGOPTP.ignoreHeadline = FALSE;
-	LEGOPTP.ignoreNonRoster = FALSE;
-	LEGOPTP.excludeGroupChatsFromIgnore = TRUE;
-	LEGOPTP.useDock = true;
-	LEGOPTP.dockDCstyle = win ? TRUE: FALSE;
-	LEGOPTP.dockHideMW = FALSE;
-	LEGOPTP.dockToolMW = FALSE;
-#ifdef Q_WS_MAC
-	LEGOPTP.alertStyle = 0;
-#else
-	LEGOPTP.alertStyle = 2;
-#endif
-	LEGOPTP.popupMsgs = FALSE;
-	LEGOPTP.popupChats = FALSE;
-	LEGOPTP.popupHeadlines = FALSE;
-	LEGOPTP.popupFiles = FALSE;
-	LEGOPTP.noAwayPopup = FALSE;
-	LEGOPTP.noUnlistedPopup = false;
-	LEGOPTP.raise = FALSE;
-	LEGOPTP.incomingAs = 0;
-	LEGOPTP.askOnline = FALSE;
-	LEGOPTP.askOffline = FALSE;
-	LEGOPTP.rosterAnim = TRUE;
-	LEGOPTP.autoVCardOnLogin = true;
-	LEGOPTP.xmlConsoleOnLogin = false;
-	LEGOPTP.asAway = 10;
-	LEGOPTP.asXa = 30;
-	LEGOPTP.asOffline = 0;
-	LEGOPTP.use_asAway = TRUE;
-	LEGOPTP.use_asXa = TRUE;
-	LEGOPTP.use_asOffline = FALSE;
-	LEGOPTP.asMessage = QObject::tr("Auto Status (idle)");
-	LEGOPTP.scrollTo = TRUE;
-	LEGOPTP.useEmoticons = false;
-	LEGOPTP.alertOpenChats = true;
-	LEGOPTP.raiseChatWindow = false;
-	LEGOPTP.showSubjects = true;
-	LEGOPTP.showCounter = false;
-	LEGOPTP.chatSays = false;
-	LEGOPTP.showGroupCounts = true;
-	LEGOPTP.smallChats = false;
-	LEGOPTP.brushedMetal = false;
-	LEGOPTP.chatLineEdit = true;
-	LEGOPTP.useTabs = false;
-	LEGOPTP.usePerTabCloseButton = true;
-	LEGOPTP.putTabsAtBottom = false;
-	LEGOPTP.autoRosterSize = false;
-	LEGOPTP.autoRosterSizeGrowTop = false;
-	LEGOPTP.autoResolveNicksOnAdd = false;
-	LEGOPTP.chatBgImage = "";
-	LEGOPTP.rosterBgImage = "";
-	LEGOPTP.autoCopy = false;
-	LEGOPTP.useCaps = true;
-	LEGOPTP.useRC = false;
-
-	LEGOPTP.sp.clear();
-	QString name;
-	name = QObject::tr("Away from desk");
-	LEGOPTP.sp[name] = StatusPreset(name, QObject::tr("I am away from my desk.  Leave a message."), STATUS_AWAY);;
-	name = QObject::tr("Showering");
-	LEGOPTP.sp[name] = StatusPreset(name, QObject::tr("I'm in the shower.  You'll have to wait for me to get out."), STATUS_AWAY);
-	name = QObject::tr("Eating");
-	LEGOPTP.sp[name] = StatusPreset(name, QObject::tr("Out eating.  Mmmm.. food."), STATUS_AWAY);
-	name = QObject::tr("Sleep");
-	LEGOPTP.sp[name] = StatusPreset(name, QObject::tr("Sleep is good.  Zzzzz"),STATUS_DND);
-	name = QObject::tr("Work");
-	LEGOPTP.sp[name] = StatusPreset(name, QObject::tr("Can't chat.  Gotta work."), STATUS_DND);
-	name = QObject::tr("Air");
-	LEGOPTP.sp[name] = StatusPreset(name, QObject::tr("Stepping out to get some fresh air."), STATUS_AWAY);
-	name = QObject::tr("Movie");
-	LEGOPTP.sp[name] = StatusPreset(name, QObject::tr("Out to a movie.  Is that OK with you?"), STATUS_AWAY);
-	name = QObject::tr("Secret");
-	LEGOPTP.sp[name] = StatusPreset(name, QObject::tr("I'm not available right now and that's all you need to know."), STATUS_XA);
-	name = QObject::tr("Out for the night");
-	LEGOPTP.sp[name] = StatusPreset(name, QObject::tr("Out for the night."), STATUS_AWAY);
-	name = QObject::tr("Greece");
-	LEGOPTP.sp[name] = StatusPreset(name, QObject::tr("I have gone to a far away place.  I will be back someday!"), STATUS_XA);
- 	LEGOPTP.recentStatus.clear();
-
-	LEGOPTP.color[cOnline]    = QColor("#000000");
-	LEGOPTP.color[cListBack]  = QColor("#FFFFFF");
-	LEGOPTP.color[cAway]      = QColor("#004BB4");
-	LEGOPTP.color[cDND]       = QColor("#7E0000");
-	LEGOPTP.color[cOffline]   = QColor("#646464");
-	LEGOPTP.color[cStatus]    = QColor("#808080");
-	LEGOPTP.color[cProfileFore] = QColor("#FFFFFF");
-	LEGOPTP.color[cProfileBack] = QColor("#969696");
-	LEGOPTP.color[cGroupFore] = QColor("#5A5A5A");
-	LEGOPTP.color[cGroupBack] = QColor("#F0F0F0");
-	LEGOPTP.color[cAnimFront] = QColor("#000000");
-	LEGOPTP.color[cAnimBack] 	= QColor("#969696");
-
-	LEGOPTP.font[fRoster] = QApplication::font().toString();
-	LEGOPTP.font[fMessage] = QApplication::font().toString();
-	LEGOPTP.font[fChat] = QApplication::font().toString();
-	{
-		QFont font = QApplication::font();
-		font.setPointSize( font.pointSize() - 2 );
-		LEGOPTP.font[fPopup] = font.toString();
-	}
-	LEGOPTP.clNewHeadings = false;
-	LEGOPTP.outlineHeadings = false;
-
-	LEGOPTP.player = "play";
-	LEGOPTP.noAwaySound = FALSE;
-
-	LEGOPTP.onevent[eMessage]    = ApplicationInfo::resourcesDir() + "/sound/chat2.wav";
-	LEGOPTP.onevent[eChat1]      = ApplicationInfo::resourcesDir() + "/sound/chat1.wav";
-	LEGOPTP.onevent[eChat2]      = ApplicationInfo::resourcesDir() + "/sound/chat2.wav";
-	LEGOPTP.onevent[eSystem]     = ApplicationInfo::resourcesDir() + "/sound/chat2.wav";
-	LEGOPTP.onevent[eHeadline]   = ApplicationInfo::resourcesDir() + "/sound/chat2.wav";
-	LEGOPTP.onevent[eOnline]     = ApplicationInfo::resourcesDir() + "/sound/online.wav";
-	LEGOPTP.onevent[eOffline]    = ApplicationInfo::resourcesDir() + "/sound/offline.wav";
-	LEGOPTP.onevent[eSend]       = ApplicationInfo::resourcesDir() + "/sound/send.wav";
-	LEGOPTP.onevent[eIncomingFT] = ApplicationInfo::resourcesDir() + "/sound/ft_incoming.wav";
-	LEGOPTP.onevent[eFTComplete] = ApplicationInfo::resourcesDir() + "/sound/ft_complete.wav";
-
-
-	LEGOPTP.sizeEventDlg = EventDlg::defaultSize();
-	LEGOPTP.sizeChatDlg = ChatDlg::defaultSize();
-	LEGOPTP.sizeTabDlg = ChatDlg::defaultSize(); //TODO: no!
-
-	LEGOPTP.jidComplete = true;
-	LEGOPTP.grabUrls = false;
-	LEGOPTP.noGCSound = true;
-
-	// toolbars
-	LEGOPTP.toolbars.clear();
-
-	Options::ToolbarPrefs tbDef;
-	tbDef.name = QString::null;
-	tbDef.on = false;
-	tbDef.locked = false;
-	tbDef.stretchable = false;
-	tbDef.keys.clear();
-
-	tbDef.dock = Qt::DockTop;
-	tbDef.nl = true;
-	tbDef.extraOffset = 0;
-
-	tbDef.dirty = true;
-
-	{
-		Options::ToolbarPrefs tb[3];
-		uint i;
-		for (i = 0; i < sizeof(tb)/sizeof(Options::ToolbarPrefs); i++) {
-			tb[i] = tbDef;
-			tb[i].index = i + 1;
-		}
-
-		bool defaultEnableToolbars;
-#ifdef Q_WS_MAC
-		defaultEnableToolbars = false;
-#else
-		defaultEnableToolbars = true;
-#endif
-
-		// Imitate old Psi button layout by default
-		tb[0].name = QObject::tr("Buttons");
-		tb[0].on = defaultEnableToolbars;
-		tb[0].locked = true;
-		tb[0].stretchable = true;
-		tb[0].keys << "button_options" << "button_status";
-		tb[0].dock = Qt::DockBottom;
-
-		tb[1].name = QObject::tr("Show contacts");
-		tb[1].on = false;
-		tb[1].locked = true;
-		tb[1].keys << "show_offline" << "show_hidden" << "show_agents" << "show_self" << "show_statusmsg"; 
-
-		tb[2].name = QObject::tr("Event notifier");
-		tb[2].on = false;
-		tb[2].locked = true;
-		tb[2].stretchable = true;
-		tb[2].keys << "event_notifier";
-		tb[2].dock = Qt::DockBottom;
-		tb[2].index = 0;
-
-		for ( i = 0; i < sizeof(tb)/sizeof(Options::ToolbarPrefs); i++ )
-			LEGOPTP.toolbars["mainWin"].append( tb[i] );
-	}
-
-	// groupchat
-	LEGOPTP.gcHighlighting = true;
-	LEGOPTP.gcHighlights.clear();
-
-	LEGOPTP.gcNickColoring = true;
-	LEGOPTP.gcNickColors.clear();
-
-	LEGOPTP.gcNickColors << "Blue";
-	LEGOPTP.gcNickColors << "Green";
-	LEGOPTP.gcNickColors << "Orange";
-	LEGOPTP.gcNickColors << "Purple";
-	LEGOPTP.gcNickColors << "Red";
-
-	// popups
-	LEGOPTP.ppIsOn        = false;
-	LEGOPTP.ppOnline      = true;
-	LEGOPTP.ppOffline     = true;
-	LEGOPTP.ppStatus      = false;
-	LEGOPTP.ppMessage     = true;
-	LEGOPTP.ppChat        = true;
-	LEGOPTP.ppHeadline    = true;
-	LEGOPTP.ppFile        = true;
-	LEGOPTP.ppJidClip     = 25;
-	LEGOPTP.ppStatusClip  = -1;
-	LEGOPTP.ppTextClip    = 300;
-	LEGOPTP.ppHideTime    = 10000; // 10 sec
-	LEGOPTP.ppBorderColor = QColor (0x52, 0x97, 0xF9);
-
-	// Bouncing of the dock (Mac OS X)
-	LEGOPTP.bounceDock = Options::BounceForever;
-
-	// lockdown
-	LEGOPTP.lockdown.roster   = false;
-	LEGOPTP.lockdown.services = false;
-
-	LEGOPTP.useTransportIconsForContacts = false;
-
-	// iconsets
-	LEGOPTP.systemIconset = "default";
-	LEGOPTP.emoticons = QStringList("default");
-	LEGOPTP.defaultRosterIconset = "default";
-
-	LEGOPTP.serviceRosterIconset.clear();
-	LEGOPTP.serviceRosterIconset["transport"]	= "crystal-service.jisp";
-	LEGOPTP.serviceRosterIconset["aim"]	= "crystal-aim.jisp";
-	LEGOPTP.serviceRosterIconset["gadugadu"]	= "crystal-gadugadu.jisp";
-	LEGOPTP.serviceRosterIconset["icq"]	= "crystal-icq.jisp";
-	LEGOPTP.serviceRosterIconset["msn"]	= "crystal-msn.jisp";
-	LEGOPTP.serviceRosterIconset["yahoo"]	= "crystal-yahoo.jisp";
-	LEGOPTP.serviceRosterIconset["sms"]	= "crystal-sms.jisp";
-
-	LEGOPTP.customRosterIconset.clear();
-
-	// roster sorting
-	LEGOPTP.rosterContactSortStyle = Options::ContactSortStyle_Status;
-	LEGOPTP.rosterGroupSortStyle   = Options::GroupSortStyle_Alpha;
-	LEGOPTP.rosterAccountSortStyle = Options::AccountSortStyle_Alpha;
-
-	// disco dialog
-	LEGOPTP.discoItems = false;
-	LEGOPTP.discoInfo  = true;
-
-	// auto-auth
-	LEGOPTP.autoAuth = false;
-
-	// Notify authorization
-	LEGOPTP.notifyAuth = false;
-
-	// message events
-	LEGOPTP.messageEvents = true;
-	LEGOPTP.inactiveEvents = false;
-
-	// event priority
-	LEGOPTP.eventPriorityHeadline = 0;
-	LEGOPTP.eventPriorityChat     = 1;
-	LEGOPTP.eventPriorityMessage  = 1;
-	LEGOPTP.eventPriorityAuth     = 2;
-	LEGOPTP.eventPriorityFile     = 3;
-	LEGOPTP.eventPriorityFile     = 2;
-
-	// Last used path remembering
-	LEGOPTP.lastPath = QDir::homeDirPath();
-	LEGOPTP.lastSavePath = QDir::homeDirPath();
-
-	// data transfer
-	LEGOPTP.dtPort = 8010;
-	LEGOPTP.dtExternal = "";
-
-}
-#endif
 
 static ToolbarPrefs loadToolbarData( const QDomElement &e )
 {
@@ -898,10 +623,10 @@ bool OptionsMigration::fromFile(const QString &fname)
 
 	QDomElement base = doc.documentElement();
 	if(base.tagName() != "psiconf")
-		return FALSE;
+		return false;
 	confver = base.attribute("version");
 	if(confver != "1.0")
-		return FALSE;
+		return false;
 
 	readEntry(base, "progver", &progver);
 
@@ -1523,7 +1248,7 @@ bool OptionsMigration::fromFile(const QString &fname)
 		}
 	}
 
-	return TRUE;
+	return true;
 }
 
 void OptionsMigration::lateMigration()
@@ -1617,36 +1342,36 @@ bool profileExists(const QString &_name)
 	QStringList list = getProfilesList();
 	for(QStringList::ConstIterator it = list.begin(); it != list.end(); ++it) {
 		if((*it).lower() == name)
-			return TRUE;
+			return true;
 	}
-	return FALSE;
+	return false;
 }
 
 bool profileNew(const QString &name)
 {
 	if(name.isEmpty())
-		return FALSE;
+		return false;
 
 	// verify the string is sane
 	for(int n = 0; n < (int)name.length(); ++n) {
 		if(!name.at(n).isLetterOrNumber())
-			return FALSE;
+			return false;
 	}
 
 	// make it
 	QDir d(ApplicationInfo::profilesDir());
 	if(!d.exists())
-		return FALSE;
+		return false;
 	QDir p(ApplicationInfo::profilesDir() + "/" + name);
 	if(!p.exists()) {
 	        if (!d.mkdir(name))
-			return FALSE;
+			return false;
 	}
 
 	p.mkdir("history");
 	p.mkdir("vcard");
 
-	return TRUE;
+	return true;
 }
 
 bool profileRename(const QString &oldname, const QString &name)
@@ -1654,17 +1379,17 @@ bool profileRename(const QString &oldname, const QString &name)
 	// verify the string is sane
 	for(int n = 0; n < (int)name.length(); ++n) {
 		if(!name.at(n).isLetterOrNumber())
-			return FALSE;
+			return false;
 	}
 
 	// locate the folder
 	QDir d(ApplicationInfo::profilesDir());
 	if(!d.exists())
-		return FALSE;
+		return false;
 	if(!d.rename(oldname, name))
-		return FALSE;
+		return false;
 
-	return TRUE;
+	return true;
 }
 
 static bool folderRemove(const QDir &_d)
@@ -1678,7 +1403,7 @@ static bool folderRemove(const QDir &_d)
 		QFileInfo info(d, *it);
 		if(info.isDir()) {
 			if(!folderRemove(QDir(info.filePath())))
-				return FALSE;
+				return false;
 		}
 		else {
 			//printf("deleting [%s]\n", info.filePath().latin1());
@@ -1687,18 +1412,18 @@ static bool folderRemove(const QDir &_d)
 	}
 	QString name = d.dirName();
 	if(!d.cdUp())
-		return FALSE;
+		return false;
 	//printf("removing folder [%s]\n", d.filePath(name).latin1());
 	d.rmdir(name);
 
-	return TRUE;
+	return true;
 }
 
 bool profileDelete(const QString &path)
 {
 	QDir d(path);
 	if(!d.exists())
-		return TRUE;
+		return true;
 
 	return folderRemove(QDir(path));
 }
