@@ -89,12 +89,23 @@
 #include "globalshortcutmanager.h"
 #include "desktoputil.h"
 #include "tabmanager.h"
+#include "capsmanager.h"
+#include "avcall/avcall.h"
+#include "avcall/calldlg.h"
 
 
+#include "AutoUpdater/AutoUpdater.h"
+#ifdef HAVE_SPARKLE
+#include "AutoUpdater/SparkleAutoUpdater.h"
+#endif
+
 #ifdef Q_WS_MAC
 #include "mac_dock.h"
 #endif
 
+// from opt_avcall.cpp
+extern void options_avcall_update();
+
 //----------------------------------------------------------------------------
 // PsiConObject
 //----------------------------------------------------------------------------
@@ -148,7 +159,7 @@ private:
 			QFileInfo info(d, *it);
 			if(info.isDir()) {
 				if(!folderRemove(QDir(info.filePath())))
-					return FALSE;
+					return false;
 			}
 			else {
 				//printf("deleting [%s]\n", info.filePath().latin1());
@@ -157,11 +168,11 @@ private:
 		}
 		QString name = d.dirName();
 		if(!d.cdUp())
-			return FALSE;
+			return false;
 		//printf("removing folder [%s]\n", d.filePath(name).latin1());
 		d.rmdir(name);
 
-		return TRUE;
+		return true;
 	}
 };
 
@@ -257,6 +268,7 @@ public:
 	QMenuBar* defaultMenuBar;
 	CapsRegistry* capsRegistry;
 	TabManager *tabManager;
+	AutoUpdater *autoUpdater;
 };
 
 //----------------------------------------------------------------------------
@@ -280,6 +292,7 @@ PsiCon::PsiCon()
 	d->s5bServer = 0;
 	d->proxy = 0;
 	d->tuneController = 0;
+	d->autoUpdater = 0;
 
 	d->actionList = 0;
 	d->defaultMenuBar = new QMenuBar(0);
@@ -294,6 +307,7 @@ PsiCon::~PsiCon()
 	saveCapabilities();
 	delete d->capsRegistry;
 
+	delete d->autoUpdater;
 	delete d->actionList;
 	delete d->edb;
 	delete d->defaultMenuBar;
@@ -324,7 +338,7 @@ bool PsiCon::init()
 	// to options.xml only.
 	QString backupfile = optionsFile() + "-preOptionsMigration";
 	if (QFile::exists(pathToProfileConfig(activeProfile))
-		&& QFile::exists(optionsFile())
+		&& PsiOptions::exists(optionsFile())
 		&& !QFile::exists(backupfile)) {
 		QFile::copy(optionsFile(), backupfile);
 	}
@@ -348,6 +362,14 @@ bool PsiCon::init()
 	d->tuneController = new CombinedTuneController();
 #endif
 
+	// Auto updater initialization
+#ifdef HAVE_SPARKLE
+	d->autoUpdater = new SparkleAutoUpdater(ApplicationInfo::getAppCastURL());
+#endif
+	if (d->autoUpdater && PsiOptions::instance()->getOption("options.auto-update.check-on-startup").toBool()) {
+		d->autoUpdater->checkForUpdates();
+	}
+
 	// calculate the small font size
 	const int minimumFontSize = 7;
 	common_smallFontSize = qApp->font().pointSize();
@@ -357,8 +379,8 @@ bool PsiCon::init()
 	FancyLabel::setSmallFontSize( common_smallFontSize );
 	
 	
-	if (!QFile::exists(optionsFile()) && !QFile::exists(pathToProfileConfig(activeProfile))) {
-		if (!options->load(":/options/newprofile.xml")) {
+	if (!PsiOptions::exists(optionsFile())) {
+		if (!options->newProfile()) {
 			qWarning("ERROR: Failed to new profile default options");
 		}
 	}
@@ -523,7 +545,7 @@ bool PsiCon::init()
 						haveEnabled = it->opt_enabled;
 						if (it->opt_enabled) {
 							if (!PsiOptions::instance()->getOption("options.account.domain").toString().isEmpty())
-								it->jid = JIDUtil::accountFromString(Jid(it->jid).user()).bare();
+								it->jid = JIDUtil::accountFromString(Jid(it->jid).node()).bare();
 						}
 					}
 					else
@@ -532,7 +554,7 @@ bool PsiCon::init()
 				else {
 					// Overwirte locked properties
 					if (!PsiOptions::instance()->getOption("options.account.domain").toString().isEmpty())
-						it->jid = JIDUtil::accountFromString(Jid(it->jid).user()).bare();
+						it->jid = JIDUtil::accountFromString(Jid(it->jid).node()).bare();
 				}
 			}
 		}
@@ -558,10 +580,27 @@ bool PsiCon::init()
 #endif
 
 	connect(ActiveProfiles::instance(), SIGNAL(raiseMainWindow()), SLOT(raiseMainwin()));
+	connect(ActiveProfiles::instance(), SIGNAL(openUri(const QUrl &)), SLOT(doOpenUri(const QUrl &)));
+
+	DesktopUtil::setUrlHandler("xmpp", this, "doOpenUri");
+
+	if(AvCallManager::isSupported()) {
+		options_avcall_update();
+		AvCallManager::setAudioOutDevice(PsiOptions::instance()->getOption("options.media.devices.audio-output").toString());
+		AvCallManager::setAudioInDevice(PsiOptions::instance()->getOption("options.media.devices.audio-input").toString());
+		AvCallManager::setVideoInDevice(PsiOptions::instance()->getOption("options.media.devices.video-input").toString());
+		AvCallManager::setBasePort(PsiOptions::instance()->getOption("options.p2p.bytestreams.listen-port").toInt());
+		AvCallManager::setExternalAddress(PsiOptions::instance()->getOption("options.p2p.bytestreams.external-address").toString());
+	}
 
 	return true;
 }
 
+bool PsiCon::haveAutoUpdater() const
+{
+	return d->autoUpdater != 0;
+}
+
 void PsiCon::registerCaps(const QString& ext, const QStringList& features)
 {
 	DiscoItem::Identity identity = { "client", ApplicationInfo::name(), "pc" };
@@ -606,6 +645,8 @@ void PsiCon::deinit()
 		d->saveProfile(acc);
 
 	GlobalShortcutManager::clear();
+
+	DesktopUtil::unsetUrlHandler("xmpp");
 }
 
 
@@ -790,9 +831,9 @@ AccountsComboBox *PsiCon::accountsComboBox(QWidget *parent, bool online_only)
 	return acb;
 }
 
-void PsiCon::createAccount(const QString &name, const Jid &j, const QString &pass, bool opt_host, const QString &host, int port, bool legacy_ssl_probe, UserAccount::SSLFlag ssl, QString proxy)
+void PsiCon::createAccount(const QString &name, const Jid &j, const QString &pass, bool opt_host, const QString &host, int port, bool legacy_ssl_probe, UserAccount::SSLFlag ssl, QString proxy, const QString &tlsOverrideDomain, const QByteArray &tlsOverrideCert)
 {
-	d->contactList->createAccount(name, j, pass, opt_host, host, port, legacy_ssl_probe, ssl, proxy);
+	d->contactList->createAccount(name, j, pass, opt_host, host, port, legacy_ssl_probe, ssl, proxy, tlsOverrideDomain, tlsOverrideCert);
 }
 
 PsiAccount *PsiCon::createAccount(const UserAccount& acc)
@@ -947,90 +988,59 @@ void PsiCon::checkAccountsEmpty()
 	}
 }
 
-void PsiCon::doOpenUri(const QUrl &uriToOpen)
+void PsiCon::doOpenUri(const QUrl &uri)
 {
-	Q_UNUSED(uriToOpen);	
-	
-/*
-	QUrl uri(uriToOpen);	// got to copy, because setQueryDelimiters() is not const
-
-	qWarning("uri:  " + uri.toString());
+	qDebug() << "uri:  " << uri.toString();
 
 	// scheme
-
-	if (uri.scheme() != "xmpp") {	// try handling legacy URIs
-		QMessageBox::warning(0, tr("Warning"), QString("URI (link) type \"%1\" is unsupported.").arg(uri.scheme()));
+	if (uri.scheme() != "xmpp") {
+		QMessageBox::critical(0, tr("Unsupported URI type"), QString("URI (link) type \"%1\" is not supported.").arg(uri.scheme()));
+		return;
 	}
 
 	// authority
-
 	PsiAccount *pa = 0;
-	if (uri.authority().isEmpty()) {
+	//if (uri.authority().isEmpty()) {
 		pa = d->contactList->defaultAccount();
 		if (!pa) {
-			QMessageBox::warning(0, tr("Warning"), QString("You don't have any account enabled."));
-		}
-	}
-	else {
-		qWarning("uri auth: [" + uri.authority() + "]");
-
-		Jid authJid = JIDUtil::fromString(uri.authority());
-		foreach(PsiAccount* acc, d->contactList->enabledAccounts()) {
-			if (acc->jid().compare(authJid, false)) {
-				pa = acc;
-			}
-		}
-
-		if (!pa) {
-			foreach(PsiAccount* acc, d->contactList->accounts()) {
-				if (acc->jid().compare(authJid, false)) {
-					QMessageBox::warning(0, tr("Warning"), QString("The account for %1 JID is disabled right now.").arg(authJid.bare()));
-					return;	// FIX-ME: Should suggest enabling it now
-				}
-			}
-		}
-		if (!pa) {
-			QMessageBox::warning(0, tr("Warning"), QString("You don't have an account for %1.").arg(authJid.bare()));
+			QMessageBox::critical(0, tr("Error"), QString("You need to have an account configured and enabled to open URIs (links)."));
 			return;
 		}
-	}
+	//
+	// TODO: finish authority component handling
+	//
+	//} else {
+	//	qDebug() << "uri auth: [" << uri.authority() << "]");
 
-	// entity
+	//	// is there such account ready to use?
+	//	Jid authJid = JIDUtil::fromString(uri.authority());
+	//	foreach (PsiAccount* acc, d->contactList->enabledAccounts()) {
+	//		if (acc->jid().compare(authJid, false)) {
+	//			pa = acc;
+	//		}
+	//	}
 
-	QString path = uri.path();
-	if (path.startsWith('/'))	// this happens when authority part is present
-		path = path.mid(1);
-	Jid entity = JIDUtil::fromString(path);
+	//	// or maybe it is configured but not enabled?
+	//	if (!pa) {
+	//		foreach (PsiAccount* acc, d->contactList->accounts()) {
+	//			if (acc->jid().compare(authJid, false)) {
+	//				QMessageBox::error(0, tr("Error"), QString("The account for %1 JID is disabled right now.").arg(authJid.bare()));
+	//				return;	// TODO: Should suggest enabling it now
+	//			}
+	//		}
+	//	}
 
-	// query
+	//	// nope..
+	//	if (!pa) {
+	//		QMessageBox::error(0, tr("Error"), QString("You don't have an account for %1.").arg(authJid.bare()));
+	//		return;
+	//	}
+	//}
 
-	uri.setQueryDelimiters('=', ';');
+	pa->openUri(uri);
 
-	QString querytype = uri.queryItems().value(0).first;	// defaults to empty string
 
-	if (querytype == "message") {
-		if (uri.queryItemValue("type") == "chat")
-			pa->actionOpenChat(entity);
-		else {
-			pa->dj_newMessage(entity, uri.queryItemValue("body"), uri.queryItemValue("subject"), uri.queryItemValue("thread"));
-		}
-	}
-	else if (querytype == "roster") {
-		pa->openAddUserDlg(entity, uri.queryItemValue("name"), uri.queryItemValue("group"));
-	}
-	else if (querytype == "join") {
-		pa->actionJoin(entity, uri.queryItemValue("password"));
-	}
-	else if (querytype == "vcard") {
-		pa->actionInfo(entity);
-	}
-	else if (querytype == "disco") {
-		pa->actionDisco(entity, uri.queryItemValue("node"));
-	}
-	else {
-		pa->actionSendMessage(entity);
-	}
-*/}
+}
 
 void PsiCon::doToolbars()
 {
@@ -1097,6 +1107,14 @@ void PsiCon::slotApplyOptions()
 
 	updateS5BServerAddresses();
 
+	if(AvCallManager::isSupported()) {
+		AvCallManager::setAudioOutDevice(PsiOptions::instance()->getOption("options.media.devices.audio-output").toString());
+		AvCallManager::setAudioInDevice(PsiOptions::instance()->getOption("options.media.devices.audio-input").toString());
+		AvCallManager::setVideoInDevice(PsiOptions::instance()->getOption("options.media.devices.video-input").toString());
+		AvCallManager::setBasePort(PsiOptions::instance()->getOption("options.p2p.bytestreams.listen-port").toInt());
+		AvCallManager::setExternalAddress(PsiOptions::instance()->getOption("options.p2p.bytestreams.external-address").toString());
+	}
+
 	// mainwin stuff
 	d->mainwin->setWindowOpts(PsiOptions::instance()->getOption("options.ui.contactlist.always-on-top").toBool(), (PsiOptions::instance()->getOption("options.ui.systemtray.enable").toBool() && PsiOptions::instance()->getOption("options.contactlist.use-toolwindow").toBool()));
 	d->mainwin->setUseDock(PsiOptions::instance()->getOption("options.ui.systemtray.enable").toBool());
@@ -1291,6 +1309,27 @@ void PsiCon::processEvent(PsiEvent *e, ActivationType activationType)
 		return;
 	}
 
+	if(e->type() == PsiEvent::AvCallType) {
+		AvCallEvent *ae = (AvCallEvent *)e;
+		AvCall *sess = ae->takeAvCall();
+		e->account()->eventQueue()->dequeue(e);
+		e->account()->queueChanged();
+		e->account()->cpUpdate(*u);
+		if(sess) {
+			if(!sess->jid().isEmpty()) {
+				CallDlg *w = new CallDlg(e->account(), 0);
+				w->setAttribute(Qt::WA_DeleteOnClose);
+				w->setIncoming(sess);
+				bringToFront(w);
+			}
+			else {
+				QMessageBox::information(0, tr("Call ended"), tr("Other party canceled call."));
+				delete sess;
+			}
+		}
+		return;
+	}
+
 	bool isChat = false;
 	bool sentToChatWindow = false;
 	if ( e->type() == PsiEvent::Message ) {
@@ -1440,7 +1479,7 @@ void PsiCon::promptUserToCreateAccount()
 		AccountRegDlg w(proxy());
 		int n = w.exec();
 		if (n == QDialog::Accepted) {
-			contactList()->createAccount(w.jid().node(),w.jid(),w.pass(),w.useHost(),w.host(),w.port(),w.legacySSLProbe(),w.ssl(),w.proxy(),false);
+			contactList()->createAccount(w.jid().node(),w.jid(),w.pass(),w.useHost(),w.host(),w.port(),w.legacySSLProbe(),w.ssl(),w.proxy(),w.tlsOverrideDomain(), w.tlsOverrideCert(), false);
 		}
 	}
 }
