@@ -24,6 +24,7 @@
 #include "accountadddlg.h"
 #include "serverinfomanager.h"
 #include "psicon.h"
+#include "contactview.h"
 
 /**
  * Constructs new PsiContactList. \param psi will not be PsiContactList's parent though.
@@ -102,7 +103,7 @@ PsiAccount *PsiContactList::defaultAccount() const
 /**
  * Creates new PsiAccount based on some initial settings. This is used by AccountAddDlg.
  */
-void PsiContactList::createAccount(const QString& name, const Jid& j, const QString& pass, bool opt_host, const QString& host, int port, bool legacy_ssl_probe, UserAccount::SSLFlag ssl, QString proxyID, bool modify)
+void PsiContactList::createAccount(const QString& name, const Jid& j, const QString& pass, bool opt_host, const QString& host, int port, bool legacy_ssl_probe, UserAccount::SSLFlag ssl, QString proxyID, const QString &tlsOverrideDomain, const QByteArray &tlsOverrideCert, bool modify)
 {
 	UserAccount acc;
 	acc.name = name;
@@ -120,6 +121,9 @@ void PsiContactList::createAccount(const QString& name, const Jid& j, const QStr
 	acc.proxyID = proxyID;
 	acc.legacy_ssl_probe = legacy_ssl_probe;
 
+	acc.tlsOverrideCert = tlsOverrideCert;
+	acc.tlsOverrideDomain = tlsOverrideDomain;
+
 	PsiAccount *pa = loadAccount(acc);
 	emit saveAccounts();
 
@@ -187,9 +191,11 @@ PsiAccount* PsiContactList::queueLowestEventId()
  */
 PsiAccount *PsiContactList::loadAccount(const UserAccount& acc)
 {
+	beginBulkOperation();
 	PsiAccount *pa = psi_->createAccount(acc);
 	connect(pa, SIGNAL(enabledChanged()), SIGNAL(accountCountChanged()));
 	emit accountAdded(pa);
+	endBulkOperation();
 	return pa;
 }
 
@@ -198,8 +204,10 @@ PsiAccount *PsiContactList::loadAccount(const UserAccount& acc)
  */
 void PsiContactList::loadAccounts(const UserAccountList &list)
 {
+	beginBulkOperation();
 	foreach(UserAccount account, list)
 		loadAccount(account);
+	endBulkOperation();
 }
 
 /**
@@ -275,3 +283,36 @@ void PsiContactList::accountEnabledChanged()
 		enabledAccounts_.append(account);
 }
 
+static int sortColumn = -1;
+static int operationCount = 0;
+/**
+ * This function should be called when a big update inside PsiContactList is taking place
+ * to enable optimizations (currently it just turns off the sorting of ContactView).
+ */
+void PsiContactList::beginBulkOperation()
+{
+	operationCount++;
+	if (operationCount == 1) {
+		Q_ASSERT(psi());
+		Q_ASSERT(psi()->contactView());
+		sortColumn = psi()->contactView()->sortColumn();
+		Q_ASSERT(sortColumn != -1);
+		psi()->contactView()->setSorting(-1, true);
+	}
+}
+
+/**
+ * This function should be called when a big update inside PsiContactList is finished
+ * (currently it re-enables the sorting of ContactView).
+ */
+void PsiContactList::endBulkOperation()
+{
+	operationCount--;
+	if (operationCount <= 0) {
+		Q_ASSERT(psi());
+		Q_ASSERT(psi()->contactView());
+		Q_ASSERT(sortColumn != -1);
+		psi()->contactView()->setSorting(sortColumn, true);
+		sortColumn = -1;
+	}
+}
