@@ -30,7 +30,7 @@ using namespace XMPP;
 
 class PsiCon;
 class PsiAccount;
-class XMPP::Jid;
+namespace XMPP { class Jid; }
 
 class PsiContactList : public ContactList
 {
@@ -50,7 +50,7 @@ public:
 
 	UserAccountList getUserAccountList() const;
 
-	void createAccount(const QString& name, const Jid& j = "", const QString& pass = "", bool opt_host = false, const QString& host = "", int port = 5222, bool legacy_ssl_probe = true, UserAccount::SSLFlag ssl = UserAccount::SSL_Auto, QString proxyID = "", bool modify = true);
+	void createAccount(const QString& name, const Jid& j = "", const QString& pass = "", bool opt_host = false, const QString& host = "", int port = 5222, bool legacy_ssl_probe = true, UserAccount::SSLFlag ssl = UserAccount::SSL_Auto, QString proxyID = "", const QString &tlsOverrideDomain="", const QByteArray &tlsOverrideCert=QByteArray(), bool modify = true);
 	void createAccount(const UserAccount&);
 	void removeAccount(PsiAccount*);
 	void setAccountEnabled(PsiAccount*, bool enabled = TRUE);
@@ -62,6 +62,9 @@ public:
 	void link(PsiAccount*);
 	void unlink(PsiAccount*);
 
+	void beginBulkOperation();
+	void endBulkOperation();
+
 signals:
 	/**
 	 * This signal is emitted when account is loaded from disk or created
