@@ -29,7 +29,6 @@
 
 class PsiEvent;
 class UserListItem;
-struct Options;
 namespace XMPP {
 	class Status;
 	class Jid;
@@ -37,14 +36,14 @@ namespace XMPP {
 
 class PsiIconset : public QObject
 {
+	Q_OBJECT
 public:
 	static PsiIconset* instance();
 
 	bool loadSystem();
+	void reloadRoster();
 	bool loadAll();
 
-	bool optionsChanged(const Options *old); // returns 'true' if Psi needs to be restarted
-
 	Q3Dict<Iconset> roster;
 	Q3PtrList<Iconset> emoticons;
 	const Iconset &system() const;
@@ -78,6 +77,12 @@ public:
 	PsiIcon *statusPtr(UserListItem *);
 	PsiIcon status(UserListItem *);
 
+signals:
+	void emoticonsChanged();
+
+private slots:
+	void optionChanged(const QString& option);
+
 private:
 	PsiIconset();
 	~PsiIconset();
@@ -86,6 +91,9 @@ private:
 	Private *d;
 
 	static PsiIconset* instance_;
+
+	bool loadRoster();
+	void loadEmoticons();
 };
 
 #endif
