@@ -211,11 +211,19 @@ bool PsiOptions::newProfile()
 	}
 
 	setOption("options.status.auto-away.message", tr("Auto Status (idle)"));
-	
+
 	return ok;
 }
 
 
+/**
+ * Checks for existing saved Options.
+ * Does not guarantee that load succeeds if the config file was corrupted.
+ */
+bool PsiOptions::exists(QString fileName) {
+	return OptionsTree::exists(fileName);
+}
+
 /**
  * Loads the options present in the xml config file named.
  * \param file Name of the xml config file to load
@@ -306,7 +314,7 @@ void PsiOptions::autoSave(bool autoSave, QString autoFile)
  */
 void PsiOptions::saveToAutoFile()
 {
-	if (autoFile_ != "") {
+	if (!autoFile_.isEmpty()) {
 		save(autoFile_);
 	}
 }
