@@ -161,7 +161,7 @@ void PsiPopup::Private::popupClicked(int button)
 		else if ( account ) {
 			// FIXME: it should work in most cases, but
 			// maybe it's better to fix UserList::find()?
-			Jid j( jid.userHost() );
+			Jid j( jid.bare() );
 			account->actionDefault( j );
 		}
 	}
@@ -276,6 +276,11 @@ PsiPopup::PsiPopup(PopupType type, PsiAccount *acc)
 		icon= (PsiIcon *)IconsetFactory::iconPtr("psi/file");
 		doAlertIcon = true;
 		break;
+	case AlertAvCall:
+		text += PsiPopup::tr("Incoming call");
+		icon= (PsiIcon *)IconsetFactory::iconPtr("psi/call");
+		doAlertIcon = true;
+		break;
 	default:
 		break;
 	}
@@ -382,7 +387,7 @@ void PsiPopup::setData(const Jid &j, const Resource &r, const UserListItem *u, c
 		const Message *jmessage = &((MessageEvent *)event)->message();
 		QString message;
 		if ( !jmessage->subject().isEmpty() )
-			message += "<font color=\"red\"><b>" + tr("Subject:") + " " + jmessage->subject() + "</b></font><br>";
+			message += "<font color=\"red\"><b>" + tr("Subject:") + ' ' + jmessage->subject() + "</b></font><br>";
 		message += TextUtil::plain2rich( jmessage->body() );
 
 		QLabel *messageLabel = new QLabel(d->popup);
