@@ -182,9 +182,9 @@ QString TextUtil::rich2plain(const QString &in)
 					out += ' ';
 				else {
 					QChar last = out.at(out.length()-1);
-					bool ok = TRUE;
+					bool ok = true;
 					if(last.isSpace() && last != '\n')
-						ok = FALSE;
+						ok = false;
 					if(ok)
 						out += ' ';
 				}
@@ -235,24 +235,24 @@ QString TextUtil::resolveEntities(const QString &in)
 static bool linkify_pmatch(const QString &str1, int at, const QString &str2)
 {
 	if(str2.length() > (str1.length()-at))
-		return FALSE;
+		return false;
 
 	for(int n = 0; n < (int)str2.length(); ++n) {
 		if(str1.at(n+at).lower() != str2.at(n).lower())
-			return FALSE;
+			return false;
 	}
 
-	return TRUE;
+	return true;
 }
 
 static bool linkify_isOneOf(const QChar &c, const QString &charlist)
 {
 	for(int i = 0; i < (int)charlist.length(); ++i) {
 		if(c == charlist.at(i))
-			return TRUE;
+			return true;
 	}
 
-	return FALSE;
+	return false;
 }
 
 // encodes a few dangerous html characters
@@ -278,9 +278,9 @@ static QString linkify_htmlsafe(const QString &in)
 static bool linkify_okUrl(const QString &url)
 {
 	if(url.at(url.length()-1) == '.')
-		return FALSE;
+		return false;
 
-	return TRUE;
+	return true;
 }
 
 static bool linkify_okEmail(const QString &addy)
@@ -289,16 +289,16 @@ static bool linkify_okEmail(const QString &addy)
 	// at least one char for each of the three sections
 	int n = addy.find('@');
 	if(n == -1 || n == 0)
-		return FALSE;
+		return false;
 	int d = addy.find('.', n+1);
 	if(d == -1 || d == 0)
-		return FALSE;
+		return false;
 	if((addy.length()-1) - d <= 0)
-		return FALSE;
+		return false;
 	if(addy.find("..") != -1)
 		return false;
 
-	return TRUE;
+	return true;
 }
 
 /**
@@ -313,45 +313,50 @@ QString TextUtil::linkify(const QString &in)
 	QString linked, link, href;
 
 	for(int n = 0; n < (int)out.length(); ++n) {
-		isUrl = FALSE;
-		isEmail = FALSE;
+		isUrl = false;
+		isEmail = false;
 		x1 = n;
 
-		if(linkify_pmatch(out, n, "http://")) {
+		if(linkify_pmatch(out, n, "xmpp:")) {
+			n += 5;
+			isUrl = true;
+			href = "";
+		}
+		else if(linkify_pmatch(out, n, "http://")) {
 			n += 7;
-			isUrl = TRUE;
+			isUrl = true;
 			href = "";
 		}
 		else if(linkify_pmatch(out, n, "https://")) {
 			n += 8;
-			isUrl = TRUE;
+			isUrl = true;
 			href = "";
 		}
 		else if(linkify_pmatch(out, n, "ftp://")) {
 			n += 6;
-			isUrl = TRUE;
+			isUrl = true;
 			href = "";
 		}
 		else if(linkify_pmatch(out, n, "news://")) {
 			n += 7;
-			isUrl = TRUE;
+			isUrl = true;
 			href = "";
 		}
 		else if (linkify_pmatch(out, n, "ed2k://")) {
 			n += 7;
-			isUrl = TRUE;
+			isUrl = true;
 			href = "";
 		}
 		else if(linkify_pmatch(out, n, "www.")) {
-			isUrl = TRUE;
+			isUrl = true;
 			href = "http://";
 		}
 		else if(linkify_pmatch(out, n, "ftp.")) {
-			isUrl = TRUE;
+			isUrl = true;
 			href = "ftp://";
 		}
 		else if(linkify_pmatch(out, n, "@")) {
-			isEmail = TRUE;
+			isEmail = true;
 			href = "mailto:";
 		}
 
