@@ -50,7 +50,7 @@
 #endif
 
 #ifdef ICONSET_ZIP
-#	include "zip.h"
+#	include "../zip/zip.h"
 #endif
 
 #include <QApplication>
@@ -258,8 +258,9 @@ public:
 		impix = from.impix;
 		anim = from.anim ? new Anim ( *from.anim ) : 0;
 		icon = 0;
+		activatedCount = from.activatedCount;
 	}
-	
+
 	void unloadAnim()
 	{
 		if ( anim )
@@ -1012,7 +1013,7 @@ public:
 
 		QFileInfo fi(dir);
 		if ( fi.isDir() ) {
-			QFile file ( dir + "/" + fileName );
+			QFile file ( dir + '/' + fileName );
 			if (!file.open(IO_ReadOnly))
 				return ba;
 
@@ -1024,7 +1025,7 @@ public:
 			if ( !z.open() )
 				return ba;
 
-			QString n = fi.baseName(true) + "/" + fileName;
+			QString n = fi.baseName(true) + '/' + fileName;
 			if ( !z.readFile(n, &ba) ) {
 				n = "/" + fileName;
 				z.readFile(n, &ba);
@@ -1219,7 +1220,7 @@ public:
 							break;
 
 						QFileInfo ext(sound[*it]);
-						path += "/" + QCA::Hash("sha1").hashToString(QString(fi.absFilePath() + "/" + *sound[*it]).utf8()) + "." + ext.extension();
+						path += "/" + QCA::Hash("sha1").hashToString(QString(fi.absFilePath() + '/' + *sound[*it]).utf8()) + '.' + ext.extension();
 
 						QFile file ( path );
 						file.open ( IO_WriteOnly );
@@ -1233,7 +1234,7 @@ public:
 #endif
 					}
 					else {
-						icon.setSound ( fi.absFilePath() + "/" + *sound[*it] );
+						icon.setSound ( fi.absFilePath() + '/' + *sound[*it] );
 						break;
 					}
 				}
@@ -1254,8 +1255,11 @@ public:
 
 		icon.blockSignals(false);
 
-		if ( loadSuccess )
+		if ( loadSuccess ) {
 			append( name, new PsiIcon(icon) );
+		} else {
+			qWarning("can't load icon because of unknown type");
+		}
 
 		return loadSuccess;
 	}
@@ -1264,8 +1268,10 @@ public:
 	bool load(const QDomDocument &doc, const QString dir)
 	{
 		QDomElement base = doc.documentElement();
-		if ( base.tagName() != "icondef" )
+		if ( base.tagName() != "icondef" ) {
+			qWarning("failed to load iconset invalid toplevel xml element");
 			return false;
+		}
 
 		bool success = true;
 
@@ -1429,6 +1435,8 @@ bool Iconset::load(const QString &dir)
 		}
 		else
 			qWarning("Iconset::load(): Failed to load iconset: icondef.xml is invalid XML");
+	} else {
+		qWarning("Iconset::load(): Failed to load iconset.xml");
 	}
 
 	//QPixmap::setDefaultOptimization( optimization );
