@@ -163,13 +163,13 @@ QString OptionsTree::mapLookup(const QString &basename, const QVariant &key) con
 }
 
 QVariant OptionsTree::mapGet(const QString &basename, const QVariant &key, const QString &node) const {
-	return getOption(mapLookup(basename, key) + "." + node);
+	return getOption(mapLookup(basename, key) + '.' + node);
 }
 
 QVariant OptionsTree::mapGet(const QString &basename, const QVariant &key, const QString &node, const QVariant &def) const {
 	QVariantList keys = mapKeyList(basename);
 	if (keys.contains(key)) {
-		return getOption(mapLookup(basename, key) + "." + node);
+		return getOption(mapLookup(basename, key) + '.' + node);
 	} else {
 		return def;
 	}
@@ -198,7 +198,7 @@ QString OptionsTree::mapPut(const QString &basename, const QVariant &key)
 }
 
 void OptionsTree::mapPut(const QString &basename, const QVariant &key, const QString &node, const QVariant &value) {
-	setOption(mapPut(basename, key) + "." + node, value);
+	setOption(mapPut(basename, key) + '.' + node, value);
 }
 
 QVariantList OptionsTree::mapKeyList(const QString &basename) const
@@ -257,6 +257,15 @@ bool OptionsTree::loadOptions(const QString& fileName, const QString& configName
 	return loadOptions(doc.documentElement(), configName, configVersion, configNS);
 }
 
+
+/**
+ * Checks for existing saved Options.
+ * Does not guarantee that load succeeds if the config file was corrupted.
+ */
+bool OptionsTree::exists(QString fileName) {
+	return AtomicXmlFile::exists(fileName);
+}
+
 /**
  * Loads all options from an XML element
  * \param base the element to read the options from
