@@ -23,7 +23,7 @@
 
 #include <QObject>
 #include <QVariant>
-#include <QMap>
+#include <QHash>
 
 class QDomDocument;
 class QDomElement;
@@ -55,7 +55,7 @@ public:
 	~VariantTree();
 
 	void setValue(QString node, QVariant value);
-	QVariant getValue(QString node) const;
+	QVariant getValue(const QString& node) const;
 	
 	bool isInternalNode(QString node) const;
 
@@ -78,13 +78,13 @@ protected:
 	static QVariant elementToVariant(const QDomElement&);
 	static void variantToElement(const QVariant&, QDomElement&);
 	
-	static bool getKeyRest(QString node, QString &key, QString &rest);
+	static bool getKeyRest(const QString& node, QString &key, QString &rest);
 
 private:
-	QMap<QString, VariantTree*> trees_;
-	QMap<QString, QVariant> values_;
-	QMap<QString, QString> comments_;
-	QMap<QString, QDomDocumentFragment> unknowns_;		// unknown types preservation
+	QHash<QString, VariantTree*> trees_;
+	QHash<QString, QVariant> values_;
+	QHash<QString, QString> comments_;
+	QHash<QString, QDomDocumentFragment> unknowns_;		// unknown types preservation
 	
 	// needed to have a document for the fragments.
 	static QDomDocument *unknownsDoc;
