@@ -39,7 +39,7 @@
 TrayIcon::TrayIcon( QObject *parent, const char *name )
 : QObject(parent, name), pop(0), d(0)
 {
-	v_isWMDock = FALSE;
+	v_isWMDock = false;
 }
 
 /**
@@ -52,7 +52,7 @@ TrayIcon::TrayIcon( QObject *parent, const char *name )
 TrayIcon::TrayIcon( const QPixmap &icon, const QString &tooltip, QMenu *popup, QObject *parent, const char *name )
 : QObject(parent, name), pop(popup), pm(icon), tip(tooltip), d(0)
 {
-	v_isWMDock = FALSE;
+	v_isWMDock = false;
 
 	if ( !pm.width() || !pm.height() )
 		pm = QPixmap( 16, 16 );
@@ -177,7 +177,7 @@ bool TrayIcon::event( QEvent *e )
 	return QObject::event( e );
     }
 
-    return TRUE;
+    return true;
 }
 
 /**
